@@ -23,11 +23,11 @@ def schedule(args):
         schedule_org = SAPOFTO.SAPOFTO('SCHEDULE',filename='session_schedule.org')
         if not  str(session_archetype) + ' SCHEDULE' in schedule_org.keys():
             schedule_org.addChild(SAPOFTO.SAPOFTO(str(session_archetype) + ' SCHEDULE'))
-        schedule_org = schedule_org[str(session_archetype) + ' SCHEDULE')]
+        schedule_org = schedule_org[str(session_archetype) + ' SCHEDULE']
     else:
         schedule_org = SAPOFTO.SAPOFTO('SCHEDULE')
         schedule_org.addChild(SAPOFTO.SAPOFTO(str(session_archetype) + ' SCHEDULE'))
-        schedule_org = schedule_org[str(session_archetype) + ' SCHEDULE')]
+        schedule_org = schedule_org[str(session_archetype) + ' SCHEDULE']
     session_id = input('Please input the session\'s ID, or press enter to autogenerate a new ID...')
     if session_id == '':
         if os.path.isdir(os.path.join('sessions',session_archetype)):
